# Socks5

Socks5 Server/Client by asyncio.

## Reference link:

* [RFC1928](https://www.ietf.org/rfc/rfc1928.txt)
* [RFC1929](https://www.ietf.org/rfc/rfc1929.txt)
* [Socks5协议](https://abersheeran.com/articles/Socks5/)
